@@ -1,9 +1,8 @@
+import six
 from astropy import units as u
 from astropy.io import fits
 from astropy import constants
-import astropy.units as u
 from astropy import wcs
-from astropy.extern import six
 import numpy as np
 import warnings
 
@@ -95,6 +94,9 @@ class Beam(u.Quantity):
         if minor is None:
             minor = major
 
+        if minor > major:
+            raise ValueError("Minor axis greater than major axis.")
+
         self = super(Beam, cls).__new__(cls, _to_area(major,minor).value, u.sr)
         self._major = major
         self._minor = minor
@@ -468,7 +470,11 @@ class Beam(u.Quantity):
             raise TypeError("freq must be a Quantity object. "
                             "Try 'freq*u.Hz' or another equivalent unit.")
 
-        return u.brightness_temperature(self.sr, freq)
+        try:
+            return u.brightness_temperature(beam_area=self.sr, frequency=freq)
+        except TypeError:
+            # old astropy used ordered arguments
+            return u.brightness_temperature(self.sr, freq)
 
     def jtok(self, freq, value=1.0*u.Jy):
         """
