@@ -3,4 +3,5 @@ def get_package_data():
         _ASTROPY_PACKAGE_NAME_ + '.tests': ['coveragerc',
                                             'data/*.fits.gz',
                                             'data/*.tar.gz',
-                                            'data/*hdr']}
+                                            'data/*hdr',
+                                            'data/*.csv']}
